@@ -7,11 +7,13 @@ from django.db.models import Q
 
 from pybb import defaults
 
+
 def _resolve_class(name):
     """ resolves a class function given as string, returning the function """
     if not name: return False
     modname, funcname = name.rsplit('.', 1)
-    return getattr(import_module(modname), funcname)() 
+    return getattr(import_module(modname), funcname)()
+
 
 class DefaultPermissionHandler(object):
     """ 
@@ -31,26 +33,26 @@ class DefaultPermissionHandler(object):
     def filter_categories(self, user, qs):
         """ return a queryset with categories `user` is allowed to see """
         return qs.filter(hidden=False) if not user.is_staff else qs
-    
+
     def may_view_category(self, user, category):
         """ return True if `user` may view this category, False if not """
         return user.is_staff or not category.hidden
-    
+
     # 
     # permission checks on forums
     # 
     def filter_forums(self, user, qs):
-        """ return a queryset with forums `user` is allowed to see """                
+        """ return a queryset with forums `user` is allowed to see """
         return qs.filter(Q(hidden=False) & Q(category__hidden=False)) if not user.is_staff else qs
-    
+
     def may_view_forum(self, user, forum):
         """ return True if user may view this forum, False if not """
         return user.is_staff or ( forum.hidden == False and forum.category.hidden == False )
-    
+
     def may_create_topic(self, user, forum):
         """ return True if `user` is allowed to create a new topic in `forum` """
         return user.has_perm('pybb.add_post')
-    
+
     #
     # permission checks on topics
     # 
@@ -60,55 +62,58 @@ class DefaultPermissionHandler(object):
             qs = qs.filter(Q(forum__hidden=False) & Q(forum__category__hidden=False))
         if not user.is_superuser:
             if user.is_authenticated():
-                qs = qs.filter(Q(forum__moderators=user) | Q(user=user) | Q(on_moderation=False))
+                qs = qs.filter(Q(forum__moderators=user) | Q(user=user) | Q(on_moderation=False)).distinct()
             else:
                 qs = qs.filter(on_moderation=False)
         return qs
-    
+
     def may_view_topic(self, user, topic):
         """ return True if user may view this topic, False otherwise """
         if user.is_superuser:
             return True
-        if not user.is_staff and ( topic.forum.hidden or topic.forum.category.hidden ):
-            return False # only staff may see hidden forum / category             
+        if not user.is_staff and (topic.forum.hidden or topic.forum.category.hidden):
+            return False  # only staff may see hidden forum / category
         if topic.on_moderation:
-            return user.is_authenticated() and ( user == topic.user or user in topic.forum.moderators ) 
+            return user.is_authenticated() and (user == topic.user or user in topic.forum.moderators)
         return True
-    
+
     def may_moderate_topic(self, user, topic):
         return user.is_superuser or user in topic.forum.moderators.all()
-    
+
     def may_close_topic(self, user, topic):
         """ return True if `user` may close `topic` """
         return self.may_moderate_topic(user, topic)
-    
+
     def may_open_topic(self, user, topic):
         """ return True if `user` may open `topic` """
         return self.may_moderate_topic(user, topic)
-    
+
     def may_stick_topic(self, user, topic):
         """ return True if `user` may stick `topic` """
         return self.may_moderate_topic(user, topic)
-    
+
     def may_unstick_topic(self, user, topic):
         """ return True if `user` may unstick `topic` """
         return self.may_moderate_topic(user, topic)
-    
+
     def may_create_post(self, user, topic):
         """ return True if `user` is allowed to create a new post in `topic` """
-        # if topic is hidden, only staff may post
+
         if topic.forum.hidden and (not user.is_staff):
+            # if topic is hidden, only staff may post
             return False
-        # if topic is closed, only staff may post
+
         if topic.closed and (not user.is_staff):
+            # if topic is closed, only staff may post
             return False
+
         # only user which have 'pybb.add_post' permission may post
         return user.has_perm('pybb.add_post')
-    
+
     def may_post_as_admin(self, user):
         """ return True if `user` may post as admin """
         return user.is_staff
-    
+
     #
     # permission checks on posts
     #    
@@ -122,7 +127,7 @@ class DefaultPermissionHandler(object):
         if not defaults.PYBB_PREMODERATION or user.is_superuser:
             # superuser may see all posts, also if premoderation is turned off moderation 
             # flag is ignored
-            return qs 
+            return qs
         elif user.is_authenticated():
             # post is visible if user is author, post is not on moderation, or user is moderator
             # for this forum
@@ -131,28 +136,29 @@ class DefaultPermissionHandler(object):
             # anonymous user may not see posts which are on moderation
             qs = qs.filter(on_moderation=False)
         return qs
-    
+
     def may_view_post(self, user, post):
         """ return True if `user` may view `post`, False otherwise """
         if user.is_superuser:
             return True
         if post.on_moderation:
             return post.user == user or user in post.topic.forum.moderators.all()
-        return True  
-    
+        return True
+
     def may_edit_post(self, user, post):
         """ return True if `user` may edit `post` """
         return user.is_superuser or post.user == user or self.may_moderate_topic(user, post.topic)
-        
+
     def may_delete_post(self, user, post):
         """ return True if `user` may delete `post` """
         return self.may_moderate_topic(user, post.topic)
-    
+
     #
     # permission checks on users
     #
     def may_block_user(self, user, user_to_block):
         """ return True if `user` may block `user_to_block` """
         return user.has_perm('pybb.block_users')
-    
+
+
 perms = _resolve_class(defaults.PYBB_PERMISSION_HANDLER)
\ No newline at end of file
